@@ -1,9 +1,10 @@
 #pragma once
 #include <string>
 #include <memory>
+#include <ostream>
 #include <string.h>
 #include <type_traits>
-#include <panda/string_view.h>
+#include "string_view.h"
 
 namespace panda { namespace log {
 
@@ -63,8 +64,8 @@ enum Level {
 };
 
 struct CodePoint {
-    std::string_view file;
-    uint32_t         line;
+    string_view file;
+    uint32_t    line;
 
     std::string to_string () const;
 };
@@ -100,7 +101,7 @@ void set_logger (const Func& f) { set_logger(new details::CallbackLogger<Func>(f
 inline bool should_log (Level level, const CodePoint& cp) { return level >= details::min_level && details::ilogger && details::ilogger->should_log(level, cp); }
 
 struct escaped {
-    std::string_view src;
+    string_view src;
 };
 std::ostream& operator<< (std::ostream&, const escaped&);
 
